///// CircuitDrawer.java /////
/**
 * Main Class of the Drawer. Set the GUI.
 * @author Jesus Márquez Barrera. 
 */

import javax.swing.*;
import javax.swing.JFrame;

import java.awt.*;
import java.awt.event.*;

public class CircuitDrawer {
	public static void main(String[] args) {
		CircuitDrawer_GUI drawer_gui = new CircuitDrawer_GUI();
		drawer_gui.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		drawer_gui.setVisible(true);
	}
}

class CircuitDrawer_GUI extends JFrame{

	public CircuitDrawer_GUI(){
		setTitle("My First Circuit Drawer");
		setExtendedState(JFrame.MAXIMIZED_BOTH);
		setLayout(new BorderLayout(10,0));

		Matrix matrix = makeMatrix();
		add(matrix.getView(),BorderLayout.CENTER);
		JPanel drawerButtonMenu = new ButtonMenu(matrix);
		add(drawerButtonMenu,BorderLayout.LINE_START);
		setJMenuBar(createDrawerMenuBar(matrix));
	}

	private Matrix makeMatrix(){
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		int panewidth = screenSize.width - 100;
		int paneheight = screenSize.height - 110;
		int topLeftX = 0;
		int topLeftY = 10;
		Matrix matrix = new Matrix(panewidth,paneheight,topLeftX,topLeftY,12,false);//dimensions of panel, vertical cells shown.
				
		for(int j=11;j<15;j++){
			MatrixElement me = new MatrixElement();
			me.setMyElement(new Wire(matrix.getTopLeftX()+j*matrix.getCellShownSize(),matrix.getTopLeftY()+5*matrix.getCellShownSize(),matrix.getCellShownSize()));
			matrix.addElement(me,j,5);
			MatrixElement me1 = new MatrixElement();
			me1.setMyElement(new Wire(matrix.getTopLeftX()+j*matrix.getCellShownSize(),matrix.getTopLeftY()+6*matrix.getCellShownSize(),matrix.getCellShownSize()));
			matrix.addElement(me1,j,6);
		}

		return matrix;
	}

	private JMenuBar createDrawerMenuBar(Matrix matrix){ 
		JMenuBar mb = new JMenuBar();

		FileMenuListener fl = new FileMenuListener(mb,matrix);
		EditMenuListener el = new EditMenuListener(matrix);
		//CircuitMenuListener cl = new CircuitMenuListener(matrix);
      	StateMachineListener sl = new StateMachineListener(mb,matrix);

		JMenu menu = new JMenu("File");
		mb.add(menu);

		JMenuItem menuItem = new JMenuItem("New...");
		menuItem.addActionListener(fl);
		menu.add(menuItem);

		menuItem = new JMenuItem("Save...");
      	menuItem.addActionListener(fl);
      	menu.add(menuItem);

		menuItem = new JMenuItem("Load...");
      	menuItem.addActionListener(fl);
      	menu.add(menuItem);

        menu = new JMenu ("Edit");
      	mb.add(menu);

      	menuItem = new JMenuItem("Zoom +");
      	menuItem.addActionListener(el);
      	menuItem.addActionListener(sl);
      	menu.add(menuItem);

      	menuItem = new JMenuItem("Zoom -");
      	menuItem.addActionListener(el);
      	menuItem.addActionListener(sl);
      	menu.add(menuItem);

		menu = new JMenu ("Circuit");
      	mb.add(menu);      	

      	menuItem = new JMenuItem("Check Closed");
      	//menuItem.addActionListener(cl);
      	menu.add(menuItem);
        menuItem.setEnabled(false);

        JMenu subMenu = new JMenu("Simulate");  
      	menu.add(subMenu);      	
        subMenu.setEnabled(false);

        return mb;
	}
}