///// ElectricalElement.java /////
/**
 * Superclass of electrical elements. Implements Serializable.
 * @author Jesus Márquez Barrera
 */

import java.awt.*;

import java.io.*;

public abstract class ElectricalElement implements Serializable {
	
	/**
	 * The identification number of the electrical elemtent.
	 */
	private final int myId;
	private boolean selected;// <--------------seleccionado?

	/**
	 * Constructor ElectricalElement. Initializes a new element.
	 * @param id Element number
	 */
	protected ElectricalElement(int id){
		myId=id;
		selected = false;
	}

	/**
	 * Retrieves the identification number of the element.
	 * @return myId identification number
	 */
	protected int getId() {
		return myId;
   	}

   	public boolean getSelected(){
   		return selected;
   	}

   	public void setSelected(boolean sel){
   		selected = sel;
   	}

   	/**
	 * Obtains the element's current. Implemented by subclasses.
	 * @return element's current
	 */
   	public abstract double getCurrent();
	
   	/**
	 * Obtains the element's voltage. Implemented by subclasses.
	 * @return element's voltage
	 */
   	public abstract double getVoltage();

	/**
	 * Method that allows to show the component's view in screen. Implemented by subclasses.
	 * @param g 
	 */   
	public abstract void paintView(Graphics2D g);

	public abstract void resize(int tlx, int tly, int w);

	/**
	 * Set the value of the electrical element's characteristic property (i.e resistance, capacitance or inductance). Implemented by subclasses.
	 * @param value property value
	 */   
   	public abstract void setValue(double value);
}