///// InductorView.java /////
/**
 * Class that implements the Inductor view.
 * @author Jesus Márquez Barrera
 */

import java.awt.*;
import java.awt.geom.*;

import java.io.*;

public class InductorView implements Serializable{

	private static final double xPoints[]={0      , 10.0/51, 15.0/51, 20.0/51, 25.0/51, 30.0/51, 35.0/51, 40.0/51, 1      };
  private static final double yPoints[]={26.0/51, 26.0/51, 0.0/51, 26.0/51, 0.0/51, 26.0/51, 0.0/51, 26.0/51, 26.0/51};
  private static final double y2Points[]={26.0/51, 26.0/51, 1.0, 26.0/51, 1.0, 26.0/51, 1.0, 26.0/51, 26.0/51};
  private static final Path2D.Double polyline_r = new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);
  private static final Path2D.Double polyline_u = new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);
  private static final Path2D.Double polyline_l = new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);
  private static final Path2D.Double polyline_d = new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);


  private Inductor i;
  
  static {  // static initialization block. It creates a spring of length = 1.
    // Right Inductor View
   	polyline_r.moveTo(xPoints[0], yPoints[0]);
    polyline_r.lineTo(xPoints[1], yPoints[1]);
    polyline_r.quadTo(xPoints[2], yPoints[2],xPoints[3], yPoints[3]);
    polyline_r.quadTo(xPoints[4], yPoints[4],xPoints[5], yPoints[5]);
    polyline_r.quadTo(xPoints[6], yPoints[6],xPoints[7], yPoints[7]);
    polyline_r.lineTo(xPoints[8], yPoints[8]);

    //Up Inductor View    
    polyline_u.moveTo(yPoints[0], xPoints[0]);
    polyline_u.lineTo(yPoints[1], xPoints[1]);
    polyline_u.quadTo(yPoints[2], xPoints[2],yPoints[3], xPoints[3]);
    polyline_u.quadTo(yPoints[4], xPoints[4],yPoints[5], xPoints[5]);
    polyline_u.quadTo(yPoints[6], xPoints[6],yPoints[7], xPoints[7]);
    polyline_u.lineTo(yPoints[8], xPoints[8]);

    //Left Inductor View
    polyline_l.moveTo(xPoints[0], y2Points[0]);
    polyline_l.lineTo(xPoints[1], y2Points[1]);
    polyline_l.quadTo(xPoints[2], y2Points[2],xPoints[3], y2Points[3]);
    polyline_l.quadTo(xPoints[4], y2Points[4],xPoints[5], y2Points[5]);
    polyline_l.quadTo(xPoints[6], y2Points[6],xPoints[7], y2Points[7]);
    polyline_l.lineTo(xPoints[8], y2Points[8]);

    //Down Inductor View    
    polyline_d.moveTo(y2Points[0], xPoints[0]);
    polyline_d.lineTo(y2Points[1], xPoints[1]);
    polyline_d.quadTo(y2Points[2], xPoints[2],y2Points[3], xPoints[3]);
    polyline_d.quadTo(y2Points[4], xPoints[4],y2Points[5], xPoints[5]);
    polyline_d.quadTo(y2Points[6], xPoints[6],y2Points[7], xPoints[7]);
    polyline_d.lineTo(y2Points[8], xPoints[8]);
  }

  public InductorView(Inductor _i){
  	i=_i;
  }

  public void draw(Graphics2D g){
  	int tlx = i.topLeftX();
  	int tly = i.topLeftY();
  	int w = i.width();
  	AffineTransform at = AffineTransform.getTranslateInstance(tlx,tly);
  	at.scale(w,w);
    Path2D.Double shape=new Path2D.Double();
    if(i.getDirection()==0.0){
         shape = (Path2D.Double) at.createTransformedShape(polyline_r);
         i.setDirection(1.0);
    }
    else if(i.getDirection()==1.0){
         shape = (Path2D.Double) at.createTransformedShape(polyline_u);
         i.setDirection(2.0);
    }
    else if(i.getDirection()==2.0){
         shape = (Path2D.Double) at.createTransformedShape(polyline_l);
         i.setDirection(3.0);
    }
    else{
         shape = (Path2D.Double) at.createTransformedShape(polyline_d);
         i.setDirection(0.0);
    }
    g.setColor(Color.BLACK);
    g.draw(shape);

  }
}