///// ResistorView.java /////
/**
 * Class that implements the resistor view.
 * @author Jesus Márquez Barrera
 */

import java.awt.*;
import java.awt.geom.*;

import java.io.*;

public class ResistorView implements Serializable{

  private static final double xPoints[]={0      , 10.0/51 ,13.0/51 ,19.0/51 ,25.0/51 ,31.0/51 ,37.0/51 ,40.0/51 ,1};
  private static final double yPoints[]={26.0/51, 26.0/51 ,16.0/51 ,36.0/51 ,16.0/51 ,36.0/51 ,16.0/51 ,26.0/51 ,26.0/51};
  private static final Path2D.Double polyline_h = new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);
  private static final Path2D.Double polyline_v = new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);
  private Resistor r;
  
  static {  // static initialization block. It creates a spring of length = 1.
   	// Horizontal Resistor View
   	polyline_h.moveTo (xPoints[0], yPoints[0]);
  	for (int index = 1;index < xPoints.length;index++)
     	polyline_h.lineTo(xPoints[index], yPoints[index]);

    // Vertical Resistor View
    polyline_v.moveTo (yPoints[0], xPoints[0]);
  	for (int index = 1;index < xPoints.length;index++)
     	polyline_v.lineTo(yPoints[index], xPoints[index]);
  }

  public ResistorView(Resistor _r){
  	r=_r;
  }

  public void draw(Graphics2D g){
  	int tlx = r.topLeftX();
  	int tly = r.topLeftY();
  	int w = r.width();
  	AffineTransform at = AffineTransform.getTranslateInstance(tlx,tly);
  	at.scale(w,w);
  	Path2D.Double shape = new Path2D.Double();
  	if(r.getDirection()==0.0){
  	   	shape = (Path2D.Double) at.createTransformedShape(polyline_h);
  	   	r.setDirection(1.0);
  	}
	else{
  	   	shape = (Path2D.Double) at.createTransformedShape(polyline_v);
  	   	r.setDirection(0.0);
  	}
  	g.setColor(Color.BLACK);
    g.draw(shape);

  }
}